A simple Elm architecture framework for ratatui.
The architecture is heavily inspired by iced. It provides an ergonomic interface for executing long-running tasks in the background and handling events concurrently, while only re-rendering when strictly necessary.
See the hello world example for a basic usage example.
Features
This crate works with all four officially supported ratatui backends:
There is a cargo feature for each backend implementation. These feature flags are not mutually exclusive, though if you have only one enabled that backend will be used without manual specification.
Similarly, this crate can be used with any async runtime that is integrated with byor. Three runtimes are provided:
There are also features for each runtime that behave the same as the backend features.
Modules
Structs
- App
- A ratatui application.
- AppWith
Backend - Lets you construct an
Appwith a custom backend in a more convenient way.
Enums
Traits
- Updater
- A trait for a struct that can update the state of the application.
- Viewer
- A trait for a struct that can render the state of the application.